@@ -38,7 +38,7 @@ class Py:
         if self.key is not None:
             code = re.sub(r'\$(\d)+', r"{key}_\g<1>".format(key=self.key), code)
         code = re.sub(r'\$HOOK(\.(\w+))', r'get_hook("\g<2>")', code)
-        code = re.sub(r'\$VARIABLE(\.(\w+))', r'Settings.metadata_store().get_variable("\g<2>").get_contents()', code)
+        code = re.sub(r'\$VARIABLE(\.(\w+))', r'get_variable("\g<2>").get_contents()', code)
         code = re.sub(r'typhoon\.(\w+)\.(\w+)', r'typhoon_transformations_\g<1>.\g<2>', code)
         code = code.replace('$ARG', 'component_args')
         return code
@@ -621,6 +621,7 @@ class DAGDefinitionV2(BaseModel):
     tests: Optional[Dict[str, TestCase]]
     airflow_default_args: Optional[dict] = Field(
         None, description='Arguments passed to generated Airflow DAG. Ignored if deploy target is not airflow.')
+    requirements: List[str] = Field(default_factory=lambda: [], description="Requirements needed for DAG")
 
     def guess_granularity(self) -> Granularity:
         cron = aws_schedule_to_cron(self.schedule_interval)
