@@ -17,7 +17,7 @@ class ComponentFile(Templated):
     from types import SimpleNamespace
     from typing import Optional, Any, Type
     
-    from typhoon.core import DagContext
+    from typhoon.core import DagContext, get_variable
     from typhoon.core.settings import Settings
     from typhoon.contrib.hooks.hook_factory import get_hook
     from typhoon.core.runtime import ComponentInterface, BrokerInterface, TaskInterface, ComponentArgs
